Entry

Struct Entry 

pub struct Entry { /* private fields */ }
An entry in a format 5 watch file

Implementations

Source

impl Entry

pub fn source(&self) -> Result<Option<String>, TemplateError>

Returns the source URL, expanding templates if present

Returns Ok(None) if no Source field is set and no template is present. Returns Err if template expansion fails.

pub fn matching_pattern(&self) -> Result<Option<String>, TemplateError>

Returns the matching pattern, expanding templates if present

Returns Ok(None) if no Matching-Pattern field is set and no template is present. Returns Err if template expansion fails.

pub fn as_deb822(&self) -> &Paragraph

Get the underlying paragraph

pub fn component(&self) -> Option<String>

Name of the component, if specified

pub fn get_option(&self, key: &str) -> Option<String>

Get the an option value from the entry, with fallback to defaults paragraph.

pub fn set_option(&mut self, option: WatchOption)

Set an option value in the entry using a WatchOption enum

pub fn set_option_str(&mut self, key: &str, value: &str)

Set an option value in the entry using string key and value (for backward compatibility)

pub fn delete_option(&mut self, option: WatchOption)

Delete an option from the entry using a WatchOption enum

pub fn delete_option_str(&mut self, key: &str)

Delete an option from the entry using a string key (for backward compatibility)

pub fn url(&self) -> String

Get the URL (same as source() but named url() for consistency)

pub fn version_policy(&self) -> Result<Option<VersionPolicy>, TypesParseError>

Get the version policy

pub fn script(&self) -> Option<String>

Get the script

pub fn set_source(&mut self, url: &str)

Set the source URL

pub fn set_matching_pattern(&mut self, pattern: &str)

Set the matching pattern

pub fn line(&self) -> usize

Get the line number (0-indexed) where this entry starts

pub fn mode(&self) -> Result<Mode, TypesParseError>

Retrieve the mode of the watch file entry with detailed error information.

pub fn try_convert_to_template(&mut self) -> Option<Template>

Try to detect if this entry matches a template pattern and convert it to use that template.

This analyzes the Source, Matching-Pattern, Searchmode, and Mode fields to determine if they match a known template pattern. If a match is found, the entry is converted to use the template syntax instead.

Returns

Returns Some(template) if a template was detected and applied, None if no template matches the current entry configuration.

Example
use debian_watch::deb822::WatchFile;

let mut wf = WatchFile::new();
let mut entry = wf.add_entry(
    "https://github.com/torvalds/linux/tags",
    r".*/(?:refs/tags/)?v?@ANY_VERSION@@ARCHIVE_EXT@"
);
entry.set_option_str("Searchmode", "html");

// Convert to template
if let Some(template) = entry.try_convert_to_template() {
    println!("Converted to {:?}", template);
}