pub enum PgpMode {
Auto,
Default,
Mangle,
Next,
Previous,
SelfSignature,
GitTag,
}Expand description
PGP verification mode
Variants
Auto
check possible URLs for the signature file and autogenerate a pgpsigurlmangle rule to
use it
Default
Use pgpsigurlmangle=rules to generate the candidate upstream signature file URL string from the upstream tarball URL.
If the specified pgpsigurlmangle is missing, uscan checks possible URLs for the signature file and suggests adding a pgpsigurlmangle rule.
Mangle
Use pgpsigurlmangle=rules to generate the candidate upstream signature file URL string from the upstream tarball URL.
Next
Verify this downloaded tarball file with the signature file specified in the next watch line. The next watch line must be pgpmode=previous. Otherwise, no verification occurs.
Previous
Verify the downloaded tarball file specified in the previous watch line with this signature file. The previous watch line must be pgpmode=next.
SelfSignature
Verify the downloaded file foo.ext with its self signature and extract its content tarball file as foo.
GitTag
Verify tag signature if mode=git.