Pretty

Enum Pretty 

pub enum Pretty {
    Describe,
    Pattern(String),
}
How to generate upstream version string from git tags

Variants



Describe

Use git describe to generate the version string



Pattern(String)

Use a custom pattern to generate the version string