Module linebased

Module linebased 

Line-based watch file format parser (versions 1-4)

Structs

Entry
A node in the syntax tree for $ast
EntryBuilder
Builder for creating new watchfile entries.
MatchingPattern
A node in the syntax tree for $ast
OptionList
A node in the syntax tree for OptionList
Parse
Thread-safe parse result that can be stored in incremental computation systems like Salsa. The type parameter T represents the root AST node type (e.g., WatchFile).
ParseError
Error type for parsing line-based watch files
ScriptNode
A node in the syntax tree for $ast
Url
A node in the syntax tree for $ast
Version
A node in the syntax tree for $ast
VersionPolicyNode
A node in the syntax tree for $ast
WatchFile
A node in the syntax tree for $ast
_Option
A node in the syntax tree for $ast

Enums

Lang
Second, implementing the Language trait teaches rowan to convert between these two SyntaxKind types, allowing for a nicer SyntaxNode API where “kinds” are values from our enum SyntaxKind, instead of plain u16 values.

Functions

parse_watch_file
Parse a watch file and return a thread-safe parse result. This can be stored in incremental computation systems like Salsa.