Module parse

Module parse 

Format detection and parsing for watch files

This module is only available when at least one of the linebased or deb822 features is enabled.

Structs

Parse
Thread-safe parse result for watch files, suitable for use in Salsa databases.

Enums

ParseError
Error type for parsing watch files
ParsedEntry
Parsed watch entry that can be either line-based or deb822 format
ParsedWatchFile
Parsed watch file that can be either line-based or deb822 format
WatchFileVersion
Detected watch file format

Functions

detect_version
Detect the version/format of a watch file from its content
parse
Parse a watch file with automatic format detection