Parse

Struct Parse 

pub struct Parse { /* private fields */ }
Thread-safe parse result for watch files, suitable for use in Salsa databases.

This wrapper provides a thread-safe interface around the parsed watch file, storing either a line-based parse tree or the raw text for deb822 format. The underlying lossless parse trees (based on rowan’s GreenNode) are thread-safe.

Implementations

Source

impl Parse

pub fn parse(text: &str) -> Self

Parse a watch file with automatic format detection

pub fn to_watch_file(&self) -> ParsedWatchFile

Get the parsed watch file

pub fn version(&self) -> u32

Get the version of the watch file