Line-based watch file format parser (versions 1-4)
Structs
- Entry
- A node in the syntax tree for $ast
- Entry
Builder - Builder for creating new watchfile entries.
- Matching
Pattern - A node in the syntax tree for $ast
- Option
List - A node in the syntax tree for OptionList
- Parse
- Thread-safe parse result that can be stored in incremental computation systems like Salsa. The type parameter T represents the root AST node type (e.g., WatchFile).
- Parse
Error - Error type for parsing line-based watch files
- Script
Node - A node in the syntax tree for $ast
- Url
- A node in the syntax tree for $ast
- Version
- A node in the syntax tree for $ast
- Version
Policy Node - A node in the syntax tree for $ast
- Watch
File - A node in the syntax tree for $ast
- _Option
- A node in the syntax tree for $ast
Functions
- parse_
watch_ file - Parse a watch file and return a thread-safe parse result. This can be stored in incremental computation systems like Salsa.