pub struct OptionList(/* private fields */);Expand description
A node in the syntax tree for OptionList
Implementations
Sourceimpl OptionList
impl OptionList
Sourceimpl OptionList
impl OptionList
Sourcepub fn options(&self) -> impl Iterator<Item = _Option> + '_
pub fn options(&self) -> impl Iterator<Item = _Option> + '_
Returns an iterator over all option nodes in the options list.
Sourcepub fn find_option(&self, key: &str) -> Option<_Option>
pub fn find_option(&self, key: &str) -> Option<_Option>
Find an option node by key.
Sourcepub fn has_option(&self, key: &str) -> bool
pub fn has_option(&self, key: &str) -> bool
Check if an option with the given key exists
Sourcepub fn get_option(&self, key: &str) -> Option<String>
pub fn get_option(&self, key: &str) -> Option<String>
Get the value of an option by key