WatchFile

Struct WatchFile 

pub struct WatchFile(/* private fields */);
A node in the syntax tree for $ast

Implementations

Source

impl WatchFile

pub fn line(&self) -> usize

Get the line number (0-indexed) where this node starts.

pub fn column(&self) -> usize

Get the column number (0-indexed, in bytes) where this node starts.

pub fn line_col(&self) -> (usize, usize)

Get both line and column (0-indexed) where this node starts. Returns (line, column) where column is measured in bytes from the start of the line.

Source

impl WatchFile

pub fn syntax(&self) -> &SyntaxNode<Lang>

Access the underlying syntax node

pub fn new(version: Option<u32>) -> WatchFile

Create a new watch file with specified version

pub fn version_node(&self) -> Option<Version>

Returns the version AST node of the watch file.

pub fn version(&self) -> u32

Returns the version of the watch file.

pub fn entries(&self) -> impl Iterator<Item = Entry> + '_

Returns an iterator over all entries in the watch file.

pub fn set_version(&mut self, new_version: u32)

Set the version of the watch file.

pub fn add_entry(&mut self, entry: Entry) -> Entry

Add an entry to the watch file.

Appends a new entry to the end of the watch file.

Examples
use debian_watch::linebased::{WatchFile, EntryBuilder};

let mut wf = WatchFile::new(Some(4));

// Add an entry using EntryBuilder
let entry = EntryBuilder::new("https://github.com/example/tags")
    .matching_pattern(".*/v?(\\d\\S+)\\.tar\\.gz")
    .build();
wf.add_entry(entry);

// Or use the builder pattern directly
wf.add_entry(
    EntryBuilder::new("https://example.com/releases")
        .matching_pattern(".*/(\\d+\\.\\d+)\\.tar\\.gz")
        .opt("compression", "xz")
        .version_policy("debian")
        .build()
);
pub fn from_reader<R: Read>(reader: R) -> Result<WatchFile, ParseError>

Read a watch file from a Read object.

pub fn from_reader_relaxed<R: Read>(r: R) -> Result<Self, Error>

Read a watch file from a Read object, allowing syntax errors.

pub fn from_str_relaxed(s: &str) -> Self

Parse a debian watch file from a string, allowing syntax errors.