pub struct Parse { /* private fields */ }Expand description
Thread-safe parse result for watch files, suitable for use in Salsa databases.
This wrapper provides a thread-safe interface around the parsed watch file, storing either a line-based parse tree or the raw text for deb822 format. The underlying lossless parse trees (based on rowan’s GreenNode) are thread-safe.
Implementations